==> tutti-ui-swing-3.1-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/fishing/VesselUseFeatureTableModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.fishing;

/*
 * #%L
 * Tutti :: UI
 * $Id: VesselUseFeatureTableModel.java 1385 2013-11-24 23:27:27Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-3.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/fishing/VesselUseFeatureTableModel.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.shared.application.swing.table.AbstractApplicationTableModel;
import fr.ifremer.shared.application.swing.table.ColumnIdentifier;
import org.jdesktop.swingx.table.TableColumnModelExt;

import static org.nuiton.i18n.I18n.n_;

/**
 * @author kmorin
 * @since 0.3
 */
public class VesselUseFeatureTableModel extends AbstractApplicationTableModel<VesselUseFeatureRowModel> {

    private static final long serialVersionUID = 1L;

    public static final ColumnIdentifier<VesselUseFeatureRowModel> KEY = ColumnIdentifier.newId(
            VesselUseFeatureRowModel.PROPERTY_KEY,
            n_("tutti.vesselUseFeatureTable.table.header.key"),
            n_("tutti.vesselUseFeatureTable.table.header.key"));

    public static final ColumnIdentifier<VesselUseFeatureRowModel> VALUE = ColumnIdentifier.newId(
            VesselUseFeatureRowModel.PROPERTY_VALUE,
            n_("tutti.vesselUseFeatureTable.table.header.value"),
            n_("tutti.vesselUseFeatureTable.table.header.value"));

    public VesselUseFeatureTableModel(TableColumnModelExt columnModel) {
        super(columnModel, false, false);
        setNoneEditableCols(KEY);
    }

    @Override
    public VesselUseFeatureRowModel createNewRow() {
        VesselUseFeatureRowModel result = new VesselUseFeatureRowModel();
        return result;
    }

}

==> tutti-ui-swing-3.1.1-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/fishing/VesselUseFeatureTableModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.fishing;

/*
 * #%L
 * Tutti :: UI
 * $Id: VesselUseFeatureTableModel.java 1566 2014-02-04 08:31:02Z tchemit $
 * $HeadURL: https://forge.codelutin.com/svn/tutti/tags/tutti-3.1.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/fishing/VesselUseFeatureTableModel.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.nuiton.jaxx.application.swing.table.AbstractApplicationTableModel;
import org.nuiton.jaxx.application.swing.table.ColumnIdentifier;
import org.jdesktop.swingx.table.TableColumnModelExt;

import static org.nuiton.i18n.I18n.n;

/**
 * @author kmorin
 * @since 0.3
 */
public class VesselUseFeatureTableModel extends AbstractApplicationTableModel<VesselUseFeatureRowModel> {

    private static final long serialVersionUID = 1L;

    public static final ColumnIdentifier<VesselUseFeatureRowModel> KEY = ColumnIdentifier.newId(
            VesselUseFeatureRowModel.PROPERTY_KEY,
            n("tutti.vesselUseFeatureTable.table.header.key"),
            n("tutti.vesselUseFeatureTable.table.header.key"));

    public static final ColumnIdentifier<VesselUseFeatureRowModel> VALUE = ColumnIdentifier.newId(
            VesselUseFeatureRowModel.PROPERTY_VALUE,
            n("tutti.vesselUseFeatureTable.table.header.value"),
            n("tutti.vesselUseFeatureTable.table.header.value"));

    public VesselUseFeatureTableModel(TableColumnModelExt columnModel) {
        super(columnModel, false, false);
        setNoneEditableCols(KEY);
    }

    @Override
    public VesselUseFeatureRowModel createNewRow() {
        VesselUseFeatureRowModel result = new VesselUseFeatureRowModel();
        return result;
    }

}
